@@ -2,7 +2,7 @@ from importlib import import_module
 
 import click
 
-from . import __version__
+from . import __title__, __version__
 
 PYCRYPTODOMEX_INSTALLED = True
 try:
@@ -37,22 +37,18 @@ class Cli(click.MultiCommand):
         name = name.replace("-", "_")  # fix dash to underline
         entry_point = None
         try:
-            module = import_module("gethash.cli.{}".format(name))
+            module = import_module(f"gethash.cli.{name}")
         except ImportError:
             pass
         else:
-            try:
-                main = module.main
-            except AttributeError:
-                pass
-            else:
-                if isinstance(main, click.Command):
-                    entry_point = main
+            main = getattr(module, "main", None)
+            if isinstance(main, click.Command):
+                entry_point = main
         return entry_point
 
 
 @click.command(cls=Cli, no_args_is_help=True)
-@click.version_option(__version__)
+@click.version_option(__version__, prog_name=__title__)
 def main():
     pass
 
