@@ -1,14 +1,14 @@
 from gethash.script import gethashcli, script_main
 
-NAME = "SHA3-256"
-SUFFIX = ".sha3_256"
+NAME = "SHA3-512"
+SUFFIX = ".sha3_512"
 
 
 @gethashcli(NAME, SUFFIX)
 def main(files, **kwargs):
-    """Generate and check SHA3-256."""
+    """Generate or check SHA3-512."""
 
-    from hashlib import sha3_256 as H
+    from hashlib import sha3_512 as H
 
     script_main(H(), files, **kwargs)
 
