@@ -19,11 +19,11 @@ def _glob(pathname, *, mode=1, recursive=False):
     elif mode == 2:
         yield from glob.iglob(pathname, recursive=recursive)
     else:
-        raise ValueError("invalid mode {}".format(mode))
+        raise ValueError(f"invalid mode '{mode}'")
 
 
 def glob_resolver(pathname, *, mode=1, recursive=False):
-    """Resolve glob pathname.
+    """Resolve a pathname with glob patterns.
 
     Parameters
     ----------
@@ -38,8 +38,8 @@ def glob_resolver(pathname, *, mode=1, recursive=False):
 
     Yields
     ------
-    path : str
-        The matched path.
+    matched_pathname : str
+        The matched pathname.
     """
 
     _check_int(mode, "mode")
@@ -47,11 +47,11 @@ def glob_resolver(pathname, *, mode=1, recursive=False):
 
 
 def glob_scanner(pathnames, *, mode=1, recursive=False):
-    """Resolve a list of glob pathnames.
+    """Resolve a list of pathnames with glob patterns.
 
     Parameters
     ----------
-    pathnames : str or path-like
+    pathnames : iterable of str or path-like
         A list of pathnames with glob patterns.
     mode : int, optional (default: 1)
         The mode of glob. If ``0``, disable glob pathname pattern; if ``1``,
@@ -62,8 +62,8 @@ def glob_scanner(pathnames, *, mode=1, recursive=False):
 
     Yields
     ------
-    path : str
-        The matched path.
+    matched_pathname : str
+        The matched pathname.
     """
 
     _check_int(mode, "mode")
